@@ -733,9 +733,10 @@ class fulltext_native extends \phpbb\search\base
 		* @var	array	must_not_contain_ids	Ids that cannot be taken into account for the results
 		* @var	array	must_exclude_one_ids	Ids that cannot be on the results
 		* @var	array	must_contain_ids		Ids that must be on the results
-		* @var	int		result_count			The previous result count for the format of the query
+		* @var	int		total_results			The previous result count for the format of the query
 		*										Set to 0 to force a re-count
-		* @var	bool	join_topic				Weather or not TOPICS_TABLE should be CROSS JOIN'ED
+		* @var	array	sql_array				The data on how to search in the DB at this point
+		* @var	bool	left_join_topics		Whether or not TOPICS_TABLE should be CROSS JOIN'ED
 		* @var	array	author_ary				Array of user_id containing the users to filter the results to
 		* @var	string	author_name				An extra username to search on (!empty(author_ary) must be true, to be relevant)
 		* @var	array	ex_fid_ary				Which forums not to search on
@@ -748,7 +749,7 @@ class fulltext_native extends \phpbb\search\base
 		* @var	string	sql_where				An array of the current WHERE clause conditions
 		* @var	string	sql_match				Which columns to do the search on
 		* @var	string	sql_match_where			Extra conditions to use to properly filter the matching process
-		* @var	string	group_by				Whether or not the SQL query requires a GROUP BY for the elements in the SELECT clause
+		* @var	bool	group_by				Whether or not the SQL query requires a GROUP BY for the elements in the SELECT clause
 		* @var	string	sort_by_sql				The possible predefined sort types
 		* @var	string	sort_key				The sort type used from the possible sort types
 		* @var	string	sort_dir				"a" for ASC or "d" dor DESC for the sort order used
@@ -761,8 +762,9 @@ class fulltext_native extends \phpbb\search\base
 			'must_not_contain_ids',
 			'must_exclude_one_ids',
 			'must_contain_ids',
-			'result_count',
-			'join_topic',
+			'total_results',
+			'sql_array',
+			'left_join_topics',
 			'author_ary',
 			'author_name',
 			'ex_fid_ary',
@@ -1048,6 +1050,7 @@ class fulltext_native extends \phpbb\search\base
 		* @event core.search_native_author_count_query_before
 		* @var	int		total_results		The previous result count for the format of the query.
 		*									Set to 0 to force a re-count
+		* @var	string	type				The type of search being made
 		* @var	string	select				SQL SELECT clause for what to get
 		* @var	string	sql_sort_table		CROSS JOIN'ed table to allow doing the sort chosen
 		* @var	string	sql_sort_join		Condition to define how to join the CROSS JOIN'ed table specifyed in sql_sort_table
@@ -1060,6 +1063,7 @@ class fulltext_native extends \phpbb\search\base
 		* @var	string	sort_days			Time, in days, that the oldest post showing can have
 		* @var	string	sql_time			The SQL to search on the time specifyed by sort_days
 		* @var	bool	firstpost_only		Wether or not to search only on the first post of the topics
+		* @var	string	sql_firstpost		The SQL used in the WHERE claused to filter by firstpost.
 		* @var	array	ex_fid_ary			Forum ids that must not be searched on
 		* @var	array	sql_fora			SQL query for ex_fid_ary
 		* @var	int		start				How many posts to skip in the search results (used for pagination)
@@ -1067,6 +1071,7 @@ class fulltext_native extends \phpbb\search\base
 		*/
 		$vars = array(
 			'total_results',
+			'type',
 			'select',
 			'sql_sort_table',
 			'sql_sort_join',
@@ -1079,6 +1084,7 @@ class fulltext_native extends \phpbb\search\base
 			'sort_days',
 			'sql_time',
 			'firstpost_only',
+			'sql_firstpost',
 			'ex_fid_ary',
 			'sql_fora',
 			'start',
